## Pato-man

Play your favorite arcade game, but as a duck!

## Installation

To install Pato-man, you'll need to have [Python 3](https://www.python.org/downloads/) (>= 3.6) and [pip](https://pip.pypa.io/en/stable/installing/) already installed on your computer. With those packages available, run:

```bash
pip install Pato-man
```

or

```bash
pip3 install Pato-man
```

## How to use

To start the game type:
```bash
patoman
```
